@@ -94,8 +94,6 @@ struct DisplayProperties {
 	int vertical_scale;
 };
 
-//#define HORIZ_SCALE 2
-//#define VERTICAL_SCALE 3
 #define SMALL_VFD_BYTE_SIZE 280*16/8
 #define SMALL_TALL_VFD_BYTE_SIZE 280*32/8
 #define LARGE_VFD_BYTE_SIZE 512*32/8
@@ -845,7 +843,6 @@ move_in_menu(gchar *name, gchar *ip_addr, const gint entry)
           *test_name, *test_addr;
     gint tmp_entry=0, old_entry=0;
     GConfClient *gconf_client = gconf_client_get_default();
-    GtkWidget *tmp_menu_label;
 
     my_printf("%s()\n", __PRETTY_FUNCTION__);
     /* remove it */
@@ -872,8 +869,7 @@ move_in_menu(gchar *name, gchar *ip_addr, const gint entry)
                               tmp_name[tmp_entry], NULL);
         gconf_client_set_string(gconf_client, ip_list[tmp_entry],
                               tmp_ip[tmp_entry], NULL);
-        tmp_menu_label = gtk_bin_get_child(GTK_BIN(*menu_list[tmp_entry]));
-        gtk_label_set_text(GTK_LABEL(tmp_menu_label), tmp_name[tmp_entry]);
+        gtk_button_set_label(GTK_BUTTON(*menu_list[tmp_entry]), tmp_name[tmp_entry]);
         tmp_entry++;
       } else {
         break;
@@ -889,7 +885,6 @@ add_to_menu(const gchar *name, const gchar *ip_addr)
     GConfClient *gconf_client = gconf_client_get_default();
     gchar *test_name, *test_addr;
     gint entry=0;
-    GtkWidget *tmp_menu_label;
     
     my_printf("%s()\n", __PRETTY_FUNCTION__);
 
@@ -928,15 +923,13 @@ add_to_menu(const gchar *name, const gchar *ip_addr)
         if ((tmp_name) && (tmp_ip)) {
           gconf_client_set_string(gconf_client, name_list[entry], tmp_name, NULL);
           gconf_client_set_string(gconf_client, ip_list[entry], tmp_ip, NULL);
-          tmp_menu_label = gtk_bin_get_child(GTK_BIN(*menu_list[entry]));
-          gtk_label_set_text(GTK_LABEL(tmp_menu_label), tmp_name);
+          gtk_button_set_label(GTK_BUTTON(*menu_list[entry]), tmp_name);
         }
       }
       /* add to saved configuration */
       gconf_client_set_string(gconf_client, name_list[0], name, NULL);
       gconf_client_set_string(gconf_client, ip_list[0], ip_addr, NULL);
-      tmp_menu_label = gtk_bin_get_child(GTK_BIN(*menu_list[0]));
-      gtk_label_set_text(GTK_LABEL(tmp_menu_label), name);
+      gtk_button_set_label(GTK_BUTTON(*menu_list[0]), name);
     } else { /* found_in_list == TRUE */
       move_in_menu(test_name, test_addr, entry);
     }
@@ -957,6 +950,8 @@ menu_cb_connect_new(GtkAction *action)
     
     my_printf("%s()\n", __PRETTY_FUNCTION__);
    
+    has_display = FALSE;
+
     /* Create the widgets */
     dialog = gtk_dialog_new_with_buttons(_("Add New"),
                                          GTK_WINDOW(window),
@@ -1204,7 +1199,6 @@ menu_cb_connect(gint entry)
         gtk_widget_show_all(dialog);
         gint result = gtk_dialog_run (GTK_DIALOG(dialog));
         switch (result) {
-          GtkWidget *tmp_menu_label;
 
           case GTK_RESPONSE_YES:
             while ((entry+1) < MRU_NUM) {
@@ -1215,27 +1209,23 @@ menu_cb_connect(gint entry)
                 tmp_addr = gconf_client_get_string(gconf_client, ip_list[entry+1], NULL);
                 gconf_client_set_string(gconf_client, name_list[entry], tmp_name, NULL);
                 gconf_client_set_string(gconf_client, ip_list[entry], tmp_addr, NULL);
-                tmp_menu_label = gtk_bin_get_child(GTK_BIN(*menu_list[entry]));
-                gtk_label_set_text(GTK_LABEL(tmp_menu_label), tmp_name);
+                gtk_button_set_label(GTK_BUTTON(*menu_list[entry]), tmp_name);
                 gconf_client_unset(gconf_client, ip_list[entry+1], NULL);
                 gconf_client_unset(gconf_client, name_list[entry+1], NULL);
-                tmp_menu_label = gtk_bin_get_child(GTK_BIN(*menu_list[entry+1]));
-                gtk_label_set_text(GTK_LABEL(tmp_menu_label), UNUSED_TEXT);
+                gtk_button_set_label(GTK_BUTTON(*menu_list[entry+1]), UNUSED_TEXT);
                 entry++;
               }
               else {
                 gconf_client_unset(gconf_client, name_list[entry], NULL);
                 gconf_client_unset(gconf_client, ip_list[entry], NULL);
-                tmp_menu_label = gtk_bin_get_child(GTK_BIN(*menu_list[entry]));
-                gtk_label_set_text(GTK_LABEL(tmp_menu_label), UNUSED_TEXT);
+                gtk_button_set_label(GTK_BUTTON(*menu_list[entry]), UNUSED_TEXT);
                 break;
               }
             }
             if (entry == MRU_NUM-1) {
               gconf_client_unset(gconf_client, name_list[entry], NULL);
               gconf_client_unset(gconf_client, ip_list[entry], NULL);
-              tmp_menu_label = gtk_bin_get_child(GTK_BIN(*menu_list[entry]));
-              gtk_label_set_text(GTK_LABEL(tmp_menu_label), UNUSED_TEXT);
+              gtk_button_set_label(GTK_BUTTON(*menu_list[entry]), UNUSED_TEXT);
             }
             break;
           default:
@@ -1281,6 +1271,7 @@ static gboolean
 menu_cb_connect_sb(GtkAction *action, gint i)
 {
     my_printf("%s()\n", __PRETTY_FUNCTION__);
+    has_display = FALSE;
     my_printf("%d\n", i);
     menu_cb_connect(i);
     my_printf("%s(): return TRUE\n", __PRETTY_FUNCTION__);
@@ -1294,9 +1285,7 @@ static void
 menu_init()
 {
     /* Create needed handles. */
-    GtkMenu *menu;
-    //GtkWidget *submenu;
-    //GtkWidget *menu_item;
+    HildonAppMenu *menu;
     GConfClient *gconf_client = gconf_client_get_default();
     gchar *sb_name;
     gint i;
@@ -1304,49 +1293,43 @@ menu_init()
     my_printf("%s()\n", __PRETTY_FUNCTION__);
 
     /* Get the menu of our view. */
-    menu = GTK_MENU(gtk_menu_new());
+    menu = HILDON_APP_MENU (hildon_app_menu_new ());
 
     /* Create the menu items. */
 
     /* The "Connect" submenu. */
-    //menu_item = gtk_menu_item_new_with_label(_("Connect"));
-    //gtk_menu_append(menu, menu_item);
-    //gtk_menu_item_set_submenu(GTK_MENU_ITEM(menu_item),
-            //submenu = gtk_menu_new());
-    gtk_menu_append(menu, _menu_connect_new_item
-            = gtk_menu_item_new_with_label(_("New...")));
-    gtk_menu_append(menu, _menu_connect_scan_item
-      = gtk_menu_item_new_with_label(_("Scan...")));
-    gtk_menu_append(menu, gtk_separator_menu_item_new());
+    _menu_connect_new_item = gtk_button_new_with_label("New...");
+    hildon_app_menu_append(menu, GTK_BUTTON(_menu_connect_new_item));
+
+    _menu_connect_scan_item = gtk_button_new_with_label("Scan...");
+    hildon_app_menu_append(menu, GTK_BUTTON(_menu_connect_scan_item));
+
+    /* clear menu for testing */
+    //for (i=0; i<MRU_NUM; i++)
+	//    gconf_client_unset(gconf_client, name_list[i], NULL);
     
     /* get saved soundbridge devices */
     for (i=0; i<MRU_NUM; i++) {
       sb_name = gconf_client_get_string(gconf_client, name_list[i], NULL);
-      if (sb_name) {
-        gtk_menu_append(menu,
-            *menu_list[i] = gtk_menu_item_new_with_label(sb_name));
-      } else {
-        gtk_menu_append(menu,
-            *menu_list[i] = gtk_menu_item_new_with_label(_(UNUSED_TEXT)));
-      }
+      if (sb_name)
+	*menu_list[i] = gtk_button_new_with_label(sb_name);
+      else
+	*menu_list[i] = gtk_button_new_with_label(_(UNUSED_TEXT));
+      hildon_app_menu_append(menu, GTK_BUTTON(*menu_list[i]));
     }
     
     /* We need to show menu items. */
     gtk_widget_show_all(GTK_WIDGET(menu));
 
-    hildon_window_set_menu(HILDON_WINDOW(window), menu);
+    hildon_window_set_app_menu(HILDON_WINDOW(window), menu);
 
     /* Connect the signals. */
-    g_signal_connect(G_OBJECT(_menu_connect_new_item), "activate",
-                      G_CALLBACK(menu_cb_connect_new), NULL);
+    g_signal_connect_after(_menu_connect_new_item, "clicked", G_CALLBACK (menu_cb_connect_new), NULL);
+    g_signal_connect_after(_menu_connect_scan_item, "clicked", G_CALLBACK (menu_cb_connect_scan), NULL);
+    
+    for (i=0; i<MRU_NUM; i++)
+      g_signal_connect_after(*menu_list[i], "clicked", G_CALLBACK (menu_cb_connect_sb), (gint *)i);
 
-    for (i=0; i<MRU_NUM; i++) {
-      g_signal_connect(G_OBJECT(*menu_list[i]), "activate",
-                       G_CALLBACK(menu_cb_connect_sb), (gint *)i);
-    }
-    g_signal_connect(G_OBJECT(_menu_connect_scan_item), "activate",
-                      G_CALLBACK(menu_cb_connect_scan), NULL);
-                      
     my_printf("%s(): return\n", __PRETTY_FUNCTION__);
 }
 
@@ -1357,9 +1340,6 @@ dbus_cb_default(const gchar *interface, const gchar *method,
 {
     my_printf("%s()\n", __PRETTY_FUNCTION__);
 
-    //if(!strcmp(method, "top_application"))
-        //gtk_idle_add((GSourceFunc)window_present, NULL);
-
     retval->type = DBUS_TYPE_INVALID;
 
     my_printf("%s(): return\n", __PRETTY_FUNCTION__);
